@@ -22,10 +22,6 @@
 #include "Poco/UnWindows.h"
 
 
-#if defined(_MSC_VER) && !defined(POCO_MSVC_SECURE_WARNINGS) && !defined(_CRT_SECURE_NO_DEPRECATE)
-	#define _CRT_SECURE_NO_DEPRECATE
-#endif 
-
 
 // Verify that we're built with the multithreaded 
 // versions of the runtime libraries
@@ -78,7 +74,6 @@
 	#pragma warning(disable:4351)	// new behavior: elements of array '...' will be default initialized
 	#pragma warning(disable:4355)	// 'this' : used in base member initializer list
 	#pragma warning(disable:4675)	// resolved overload was found by argument-dependent lookup
-	#pragma warning(disable:4996)	// VC++ 8.0 deprecation warnings
 #endif
 
 
